API reference
=============
The core of the simulator is composed from the following modules:

.. currentmodule:: wltp
.. autosummary::

    pandel
    model
    experiment
    idgears

Among the various tests, those running on 'sample' databases for comparing differences
with existing tool are the following:

.. currentmodule:: wltp.test
.. autosummary::

    samples_db_tests
    wltp_db_tests

The following scripts in the sources maybe used to preprocess various wltc data:

* :file:`devtools/preprocheinz.py`
* :file:`devtools/printwltcclass.py`
* :file:`devtools/csvcolumns8to2.py`



Module: :mod:`wltp.experiment`
------------------------------
.. automodule:: wltp.experiment
    :members:

Module: :mod:`wltp.model`
-------------------------
.. automodule:: wltp.model
    :members:

Module: :mod:`wltp.pandel`
--------------------------
.. automodule:: wltp.pandel
    :members:

Module: :mod:`wltp.test.samples_db_tests`
-----------------------------------------
.. automodule:: wltp.test.samples_db_tests
    :members:

Module: :mod:`wltp.test.wltp_db_tests`
--------------------------------------
.. automodule:: wltp.test.wltp_db_tests
    :members:

